
BASIC_FORM_CSS = """\
form div.title {
    font-weight: bold;
}

form br.widget {
    clear: left; /* each widget div starts on new line by default */
}

form div.widget {
    float: left;
    padding: 4px;
    padding-right: 1em;
    margin-bottom: 6px;
}

form div.widget div.widget {
    padding: 0;
    margin-bottom: 0;
}

form div.content {
    margin-left: 0.6em; /* indent content */
}

form div.content div.content {
    margin-left: 0; /* indent content only for top-level widgets */
}

form div.error {
    color: #c00;
    font-size: small;
    margin-top: .1em;
}

form div.hint {
    font-size: small;
    font-style: italic;
    margin-top: .1em;
}

form div.errornotice {
    color: #c00;
    padding: 0.5em;
    margin: 0.5em;
}

form div.FormTokenWidget {
    display: none;
}

form div.HiddenWidget {
    display: none;
}

form div.submit {
    margin-top: 0.5em;
    margin-bottom: 1em;
    padding: 0.5em;
}
"""
